# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-08 23:51
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailimages', '0018_remove_rendition_filter'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Filter',
        ),
    ]
